require "import"
import "android.content.Context"
import "android.net.wifi.WifiManager"

local WifiManager = luajava.bindClass("android.net.wifi.WifiManager")

function getWifiStatus()
    local wifiStatus = {}
    local wifiManager = service.getSystemService(Context.WIFI_SERVICE)
    
    -- Get WiFi state
    wifiStatus["wifiState"] = wifiManager.getWifiState()

    -- Get connection info
    local wifiInfo = wifiManager.getConnectionInfo()
    wifiStatus["ssid"] = wifiInfo.getSSID()
    wifiStatus["bssid"] = wifiInfo.getBSSID()
    wifiStatus["ipAddress"] = wifiInfo.getIpAddress()
    wifiStatus["linkSpeed"] = wifiInfo.getLinkSpeed() -- in Mbps
    wifiStatus["rssi"] = wifiInfo.getRssi() -- signal strength

    return wifiStatus
end

function printWifiStatus(status)
    local wifiStateStrings = {
        [0] = "DISABLING",
        [1] = "DISABLED",
        [2] = "ENABLING",
        [3] = "ENABLED",
        [4] = "UNKNOWN"
    }

    print("WiFi State: " .. wifiStateStrings[status["wifiState"]])
    print("SSID: " .. status["ssid"])
    print("BSSID: " .. status["bssid"])
    print("IP Address: " .. status["ipAddress"])
    print("Link Speed: " .. status["linkSpeed"] .. " Mbps")
    print("RSSI: " .. status["rssi"] .. " dBm")
end

function updateWifiStatus()
    local wifiStatus = getWifiStatus()
    printWifiStatus(wifiStatus)
end

-- Initial WiFi status
updateWifiStatus()

-- Implement automatic updates using a Lua table as a timer task
local timer = {
    run = function ()
        updateWifiStatus()
        local handler = Handler()
        handler.postDelayed(timer, 5000) -- 5000 milliseconds = 5 seconds
    end
}

-- Schedule the task to run every 5 seconds
local Handler = luajava.bindClass("android.os.Handler")
local handler = Handler()
handler.postDelayed(timer, 5000) -- 5000 milliseconds = 5 seconds